@@ -1,13 +1,16 @@
 import dataclasses
 import typing
 
-from . import bundle as _bundle
+from . import contributions as _contributions
 from . import enums as _enums
 from . import math as _math
-from . import overrides as _overrides
 from . import string as _string
 
+_EMPTY_CHORD = "<>"
 
+
+# TODO: move to indicators.py
+# TODO: frozen=True
 @dataclasses.dataclass(eq=False, slots=True, unsafe_hash=True)
 class Dynamic:
     r"""
@@ -44,17 +47,17 @@ class Dynamic:
         >>> dynamic_2 = abjad.Dynamic(dynamic_1)
 
         >>> dynamic_1
-        Dynamic(name='f', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2, tweaks=None)
+        Dynamic(name='f', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2)
 
         >>> dynamic_2
-        Dynamic(name='f', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2, tweaks=None)
+        Dynamic(name='f', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2)
 
     ..  container:: example
 
         Initializes niente:
 
         >>> abjad.Dynamic("niente")
-        Dynamic(name='niente', command=None, direction=Down, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=True, ordinal=NegativeInfinity(), tweaks=None)
+        Dynamic(name='niente', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=True, ordinal=NegativeInfinity())
 
     ..  container:: example
 
@@ -64,7 +67,7 @@ class Dynamic:
         >>> abjad.attach(abjad.Dynamic('f'), voice_1[0], context='Voice')
         >>> literal = abjad.LilyPondLiteral(r"\voiceOne", "opening")
         >>> abjad.attach(literal, voice_1)
-        >>> abjad.override(voice_1).DynamicLineSpanner.direction = abjad.Up
+        >>> abjad.override(voice_1).DynamicLineSpanner.direction = abjad.UP
         >>> voice_2 = abjad.Voice("c'2")
         >>> literal = abjad.LilyPondLiteral(r"\voiceTwo", "opening")
         >>> abjad.attach(literal, voice_2)
@@ -100,13 +103,19 @@ class Dynamic:
             >>
 
         >>> for leaf in abjad.select.leaves(staff):
-        ...     leaf, abjad.get.effective(leaf, abjad.Dynamic)
-        ...
-        (Note("e'8"), Dynamic(name='f', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2, tweaks=None))
-        (Note("g'8"), Dynamic(name='f', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2, tweaks=None))
-        (Note("f'8"), Dynamic(name='f', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2, tweaks=None))
-        (Note("a'8"), Dynamic(name='f', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2, tweaks=None))
-        (Note("c'2"), Dynamic(name='mf', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=1, tweaks=None))
+        ...     dynamic = abjad.get.effective(leaf, abjad.Dynamic)
+        ...     print(f"{leaf!r}:")
+        ...     print(f"    {dynamic!r}")
+        Note("e'8"):
+            Dynamic(name='f', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2)
+        Note("g'8"):
+            Dynamic(name='f', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2)
+        Note("f'8"):
+            Dynamic(name='f', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2)
+        Note("a'8"):
+            Dynamic(name='f', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2)
+        Note("c'2"):
+            Dynamic(name='mf', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=1)
 
     ..  container:: example exception
 
@@ -146,45 +155,8 @@ class Dynamic:
 
         >>> note = abjad.Note("c'4")
         >>> dynamic = abjad.Dynamic("f")
-        >>> abjad.tweak(dynamic).color = "#blue"
-        >>> abjad.attach(dynamic, note)
-        >>> abjad.show(note) # doctest: +SKIP
-
-        ..  docs::
-
-            >>> string = abjad.lilypond(note)
-            >>> print(string)
-            c'4
-            - \tweak color #blue
-            \f
-
-        Tweaks survive copy:
-
-        >>> import copy
-        >>> dynamic_1 = abjad.Dynamic("f")
-        >>> abjad.tweak(dynamic_1).color = "#blue"
-        >>> dynamic_2 = copy.copy(dynamic_1)
-        >>> note = abjad.Note("c'4")
-        >>> abjad.attach(dynamic_2, note)
-        >>> abjad.show(note) # doctest: +SKIP
-
-        ..  docs::
-
-            >>> string = abjad.lilypond(note)
-            >>> print(string)
-            c'4
-            - \tweak color #blue
-            \f
-
-        Tweaks survive replace:
-
-        >>> import copy
-        >>> import dataclasses
-        >>> dynamic_1 = abjad.Dynamic("f")
-        >>> abjad.tweak(dynamic_1).color = "#blue"
-        >>> dynamic_2 = dataclasses.replace(dynamic_1)
-        >>> note = abjad.Note("c'4")
-        >>> abjad.attach(dynamic_2, note)
+        >>> bundle = abjad.bundle(dynamic, r"- \tweak color #blue")
+        >>> abjad.attach(bundle, note)
         >>> abjad.show(note) # doctest: +SKIP
 
         ..  docs::
@@ -231,11 +203,11 @@ class Dynamic:
                 \f
             }
 
-        With ``direction=abjad.Up``:
+        With ``direction=abjad.UP``:
 
         >>> staff = abjad.Staff("c'2 c''2")
-        >>> abjad.attach(abjad.Dynamic("p", direction=abjad.Up), staff[0])
-        >>> abjad.attach(abjad.Dynamic("f", direction=abjad.Up), staff[1])
+        >>> abjad.attach(abjad.Dynamic("p"), staff[0], direction=abjad.UP)
+        >>> abjad.attach(abjad.Dynamic("f"), staff[1], direction=abjad.UP)
         >>> abjad.show(staff) # doctest: +SKIP
 
         ..  docs::
@@ -250,11 +222,11 @@ class Dynamic:
                 ^ \f
             }
 
-        With ``direction=abjad.Down``:
+        With ``direction=abjad.DOWN``:
 
         >>> staff = abjad.Staff("c'2 c''2")
-        >>> abjad.attach(abjad.Dynamic("p", direction=abjad.Down), staff[0])
-        >>> abjad.attach(abjad.Dynamic("f", direction=abjad.Down), staff[1])
+        >>> abjad.attach(abjad.Dynamic("p"), staff[0], direction=abjad.DOWN)
+        >>> abjad.attach(abjad.Dynamic("f"), staff[1], direction=abjad.DOWN)
         >>> abjad.show(staff) # doctest: +SKIP
 
         ..  docs::
@@ -315,8 +287,8 @@ class Dynamic:
         And may be overriden:
 
         >>> staff = abjad.Staff("c'2 c''2")
-        >>> abjad.attach(abjad.Dynamic('"p"', direction=abjad.Up), staff[0])
-        >>> abjad.attach(abjad.Dynamic('"f"', direction=abjad.Up), staff[1])
+        >>> abjad.attach(abjad.Dynamic('"p"'), staff[0], direction=abjad.UP)
+        >>> abjad.attach(abjad.Dynamic('"f"'), staff[1], direction=abjad.UP)
         >>> abjad.show(staff) # doctest: +SKIP
 
         ..  docs::
@@ -375,12 +347,17 @@ class Dynamic:
         }
 
         >>> for leaf in abjad.iterate.leaves(voice):
-        ...     leaf, abjad.get.effective(leaf, abjad.Dynamic)
-        ...
-        (Note("c'4"), Dynamic(name='f', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2, tweaks=None))
-        (Note("d'4"), Dynamic(name='f', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2, tweaks=None))
-        (Note("e'4"), Dynamic(name='mf', command=None, direction=None, format_hairpin_stop=False, hide=True, leak=False, name_is_textual=False, ordinal=1, tweaks=None))
-        (Note("f'4"), Dynamic(name='mf', command=None, direction=None, format_hairpin_stop=False, hide=True, leak=False, name_is_textual=False, ordinal=1, tweaks=None))
+        ...     dynamic = abjad.get.effective(leaf, abjad.Dynamic)
+        ...     print(f"{leaf!r}:")
+        ...     print(f"    {dynamic!r}")
+        Note("c'4"):
+            Dynamic(name='f', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2)
+        Note("d'4"):
+            Dynamic(name='f', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=2)
+        Note("e'4"):
+            Dynamic(name='mf', command=None, format_hairpin_stop=False, hide=True, leak=False, name_is_textual=False, ordinal=1)
+        Note("f'4"):
+            Dynamic(name='mf', command=None, format_hairpin_stop=False, hide=True, leak=False, name_is_textual=False, ordinal=1)
 
     ..  container:: example
 
@@ -475,8 +452,8 @@ class Dynamic:
             {
                 c'8
                 \mf
-                \>
                 [
+                \>
                 d'8
                 e'8
                 ]
@@ -502,7 +479,8 @@ class Dynamic:
             {
                 c'4
                 \f
-                <> \p
+                <>
+                \p
                 d'4
                 e'4
                 f'4
@@ -510,13 +488,13 @@ class Dynamic:
 
     ..  container:: example
 
-        Leaks and tweaks on the same dynamic format correctly;
-        LilyPond empty chord ``<>`` symbol appears before postevents:
+        Leaks and tweaks on the same dynamic format correctly; LilyPond empty chord
+        ``<>`` symbol appears before postevents:
 
         >>> staff = abjad.Staff("r4 d' e' f'")
         >>> dynamic = abjad.Dynamic("f", leak=True)
-        >>> abjad.tweak(dynamic).color = "#blue"
-        >>> abjad.attach(dynamic, staff[0])
+        >>> bundle = abjad.bundle(dynamic, r"- \tweak color #blue")
+        >>> abjad.attach(bundle, staff[0])
         >>> abjad.show(staff) # doctest: +SKIP
 
         >>> string = abjad.lilypond(staff)
@@ -539,7 +517,7 @@ class Dynamic:
         >>> import copy
         >>> dynamic = abjad.Dynamic("pp", leak=True)
         >>> copy.copy(dynamic)
-        Dynamic(name='pp', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=True, name_is_textual=False, ordinal=-3, tweaks=None)
+        Dynamic(name='pp', command=None, format_hairpin_stop=False, hide=False, leak=True, name_is_textual=False, ordinal=-3)
 
     ..  container:: example
 
@@ -592,7 +570,7 @@ class Dynamic:
         >>> abjad.attach(dynamic, voice[0])
         >>> abjad.override(voice).DynamicLineSpanner.staff_padding = 4
         >>> abjad.override(voice).DynamicText.X_extent = "#'(0 . 0)"
-        >>> abjad.override(voice).DynamicText.self_alignment_X = abjad.Left
+        >>> abjad.override(voice).DynamicText.self_alignment_X = abjad.LEFT
         >>> abjad.show(voice) # doctest: +SKIP
 
         ..  docs::
@@ -644,11 +622,11 @@ class Dynamic:
         >>> import dataclasses
         >>> dynamic = abjad.Dynamic("niente")
         >>> dataclasses.replace(dynamic)
-        Dynamic(name='niente', command=None, direction=Down, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=True, ordinal=NegativeInfinity(), tweaks=None)
+        Dynamic(name='niente', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=True, ordinal=NegativeInfinity())
 
         >>> dynamic = abjad.Dynamic("appena udibile", name_is_textual=True)
         >>> dataclasses.replace(dynamic)
-        Dynamic(name='appena udibile', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=True, ordinal=None, tweaks=None)
+        Dynamic(name='appena udibile', command=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=True, ordinal=None)
 
     ..  container:: example
 
@@ -695,23 +673,24 @@ class Dynamic:
 
     """
 
-    # TODO: make ``name`` mandatory; remove default
-
     name: typing.Union[str, "Dynamic"] = "f"
-    command: typing.Optional[str] = None
-    direction: typing.Union[int, _enums.VerticalAlignment, None] = None
+    command: str | None = None
     format_hairpin_stop: bool = False
     hide: bool = False
-    leak: bool = False
+    leak: bool = dataclasses.field(default=False, compare=False)
     name_is_textual: bool = False
-    ordinal: typing.Union[int, _math.Infinity, _math.NegativeInfinity, None] = None
-    tweaks: typing.Optional[_overrides.TweakInterface] = None
+    ordinal: int | _math.Infinity | _math.NegativeInfinity | None = None
 
-    _is_dataclass = True
+    context: typing.ClassVar[str] = "Voice"
+    directed: typing.ClassVar[bool] = True
+    parameter: typing.ClassVar[str] = "DYNAMIC"
+    persistent: typing.ClassVar[bool] = True
+    post_event: typing.ClassVar[bool] = True
+    spanner_stop: typing.ClassVar[bool] = True
 
     def __post_init__(self):
         if self.name is not None:
-            assert isinstance(self.name, (str, Dynamic)), repr(self.name)
+            assert isinstance(self.name, str | Dynamic), repr(self.name)
         if isinstance(self.name, Dynamic):
             name_ = self.name.name
         elif isinstance(self.name, str):
@@ -727,10 +706,6 @@ class Dynamic:
         if self.command is not None:
             assert isinstance(self.command, str), repr(self.command)
             assert self.command.startswith("\\"), repr(self.command)
-        if self.direction is not None:
-            assert self.direction in (_enums.Down, _enums.Up), repr(self.direction)
-        elif self.name == "niente" or self.effort:
-            self.direction = _enums.Down
         assert isinstance(self.format_hairpin_stop, bool), repr(
             self.format_hairpin_stop
         )
@@ -763,15 +738,8 @@ class Dynamic:
                 assert isinstance(ordinal_, prototype), repr(ordinal_)
                 ordinal = ordinal_
             self.ordinal = ordinal
-        # self._ordinal = ordinal
-        self.tweaks = _overrides.TweakInterface.set_dataclass_tweaks(self, self.tweaks)
 
-    context = "Voice"
-    parameter = "DYNAMIC"
-    persistent = True
-    spanner_stop = True
-
-    _composite_dynamic_name_to_steady_state_dynamic_name = {
+    _composite_dynamic_name_to_steady_state_dynamic_name: typing.ClassVar = {
         "fp": "p",
         "sf": "f",
         "sff": "ff",
@@ -785,7 +753,7 @@ class Dynamic:
         "rfz": "f",
     }
 
-    _dynamic_name_to_dynamic_ordinal = {
+    _dynamic_name_to_dynamic_ordinal: typing.ClassVar = {
         "ppppp": -6,
         "pppp": -5,
         "ppp": -4,
@@ -801,7 +769,7 @@ class Dynamic:
         "fffff": 6,
     }
 
-    _dynamic_names = (
+    _dynamic_names: typing.ClassVar = (
         "ppppp",
         "pppp",
         "ppp",
@@ -830,7 +798,7 @@ class Dynamic:
         "niente",
     )
 
-    _dynamic_ordinal_to_dynamic_name = {
+    _dynamic_ordinal_to_dynamic_name: typing.ClassVar = {
         -6: "ppppp",
         -5: "pppp",
         -4: "ppp",
@@ -846,13 +814,21 @@ class Dynamic:
         6: "fffff",
     }
 
-    _format_slot = "after"
+    _site: typing.ClassVar[str] = "after"
 
-    _lilypond_dynamic_commands = [_ for _ in _dynamic_names if not _ == "niente"]
+    _lilypond_dynamic_commands: typing.ClassVar = [
+        _ for _ in _dynamic_names if not _ == "niente"
+    ]
 
-    _lilypond_dynamic_alphabet = "fmprsz"
+    _lilypond_dynamic_alphabet: typing.ClassVar = "fmprsz"
 
-    _to_width = {'"f"': 2, '"mf"': 3.5, '"mp"': 3.5, '"p"': 2, "sfz": 2.5}
+    _to_width: typing.ClassVar = {
+        '"f"': 2,
+        '"mf"': 3.5,
+        '"mp"': 3.5,
+        '"p"': 2,
+        "sfz": 2.5,
+    }
 
     def __eq__(self, argument) -> bool:
         """
@@ -898,13 +874,14 @@ class Dynamic:
             return strings
         return True
 
-    def _format_effort_dynamic(self):
+    def _format_effort_dynamic(self, *, wrapper=None):
         name = self.name.strip('"')
         before = {"f": -0.4, "m": -0.1, "p": -0.1, "r": -0.1, "s": -0.3, "z": -0.2}[
             name[0]
         ]
         after = {"f": -0.2, "m": -0.1, "p": -0.25, "r": 0, "s": 0, "z": -0.2}[name[-1]]
-        direction = self.direction
+        # direction = self.direction
+        direction = wrapper.direction or _enums.DOWN
         direction = _string.to_tridirectional_lilypond_symbol(direction)
         strings = []
         strings.append(f"{direction} #(make-dynamic-script")
@@ -923,47 +900,42 @@ class Dynamic:
         return string
 
     @staticmethod
-    def _format_textual(direction, string):
-        if direction is None:
-            direction = _enums.Down
+    # def _format_textual(direction, string):
+    def _format_textual(string, *, wrapper=None):
+        if wrapper.direction is None:
+            direction = _enums.DOWN
         direction = _string.to_tridirectional_lilypond_symbol(direction)
         assert isinstance(string, str), repr(string)
         string = f'(markup #:whiteout #:normal-text #:italic "{string}")'
         string = f"{direction} #(make-dynamic-script {string})"
         return string
 
-    def _get_lilypond_format(self):
+    def _get_lilypond_format(self, *, wrapper=None):
         if self.command:
             string = self.command
         elif self.effort:
-            string = self._format_effort_dynamic()
+            string = self._format_effort_dynamic(wrapper=wrapper)
         elif self.name_is_textual:
-            string = self._format_textual(self.direction, self.name)
+            string = self._format_textual(self.name, wrapper=wrapper)
         else:
             string = rf"\{self.name}"
-            if self.direction is not None:
-                direction_ = self.direction
+            if wrapper.direction is not None:
+                direction_ = wrapper.direction
                 direction = _string.to_tridirectional_lilypond_symbol(direction_)
                 string = f"{direction} {string}"
         return string
 
-    def _get_lilypond_format_bundle(self, component=None):
-        bundle = _bundle.LilyPondFormatBundle()
+    def _get_contributions(self, *, component=None, wrapper=None):
+        contributions = _contributions.ContributionsBySite()
+        command = self._get_lilypond_format(wrapper=wrapper)
         if self.leak:
-            bundle.after.leaks.append("<>")
-        if self.tweaks:
-            tweaks = self.tweaks._list_format_contributions()
-            if self.leak:
-                bundle.after.leaks.extend(tweaks)
-            else:
-                bundle.after.articulations.extend(tweaks)
-        if not self.hide:
-            string = self._get_lilypond_format()
-            if self.leak:
-                bundle.after.leaks.append(string)
-            else:
-                bundle.after.articulations.append(string)
-        return bundle
+            contributions.after.leak.append(_EMPTY_CHORD)
+            if not self.hide:
+                contributions.after.leaks.append(command)
+        else:
+            if not self.hide:
+                contributions.after.articulations.append(command)
+        return contributions
 
     # TODO: make markup function and shorten docstring
     @property
