@@ -4,13 +4,11 @@ import dataclasses
 from . import bind as _bind
 from . import duration as _duration
 from . import enums as _enums
-from . import format as _format
 from . import get as _get
 from . import indicators as _indicators
 from . import iterate as iterate_
 from . import lilypondfile as _lilypondfile
 from . import makers as _makers
-from . import markups as _markups
 from . import metricmodulation as _metricmodulation
 from . import overrides as _overrides
 from . import pcollections as _pcollections
@@ -18,6 +16,7 @@ from . import pitch as _pitch
 from . import score as _score
 from . import select as _select
 from . import spanners as _spanners
+from . import tag as _tag
 from . import timespan as _timespan
 
 
@@ -30,7 +29,7 @@ def _illustrate_component(component):
 
 def _illustrate_markup(markup):
     lilypond_file = _lilypondfile.LilyPondFile()
-    markup = dataclasses.replace(markup, direction=None)
+    markup = dataclasses.replace(markup)
     lilypond_file.items.append(markup)
     return lilypond_file
 
@@ -143,7 +142,7 @@ def _illustrate_pitch_set(set_):
 
 
 def _illustrate_pitch_class_segment(
-    segment, markup_direction=_enums.Up, figure_name=None
+    segment, markup_direction=_enums.UP, figure_name=None
 ):
     notes = []
     for item in segment:
@@ -151,7 +150,7 @@ def _illustrate_pitch_class_segment(
         notes.append(note)
     markup = None
     if isinstance(figure_name, str):
-        figure_name = _markups.Markup(rf"\markup {figure_name}")
+        figure_name = _indicators.Markup(rf"\markup {figure_name}")
     if figure_name is not None:
         markup = figure_name
     if markup is not None:
@@ -185,7 +184,7 @@ def _illustrate_pitch_class_segment(
     bar_line = _indicators.BarLine("|.")
     _bind.attach(bar_line, leaf)
     string = r"\override Score.BarLine.transparent = ##f"
-    command = _overrides.LilyPondLiteral(string, "after")
+    command = _indicators.LilyPondLiteral(string, "after")
     last_leaf = _select.leaf(score, -1)
     _bind.attach(command, last_leaf)
     lilypond_file = _lilypondfile.LilyPondFile([preamble, score])
@@ -200,14 +199,13 @@ def _illustrate_timespan(timespan):
 _class_to_method = dict(
     [
         (_score.Component, _illustrate_component),
-        (_markups.Markup, _illustrate_markup),
+        (_indicators.Markup, _illustrate_markup),
         (_metricmodulation.MetricModulation, _illustrate_metric_modulation),
+        (_pcollections.PitchClassSegment, _illustrate_pitch_class_segment),
+        (_pcollections.PitchSegment, _illustrate_pitch_segment),
+        (_pcollections.PitchSet, _illustrate_pitch_set),
         (_timespan.OffsetCounter, _illustrate_markup_maker),
         (_pcollections.PitchRange, _illustrate_pitch_range),
-        (_pcollections.PitchClassSet, _illustrate_pitch_class_set),
-        (_pcollections.PitchSegment, _illustrate_pitch_segment),
-        (_pcollections.PitchClassSegment, _illustrate_pitch_class_segment),
-        (_pcollections.PitchSet, _illustrate_pitch_set),
         (_timespan.Timespan, _illustrate_timespan),
         (_timespan.TimespanList, _illustrate_markup_maker),
     ]
@@ -224,17 +222,17 @@ def attach_markup_struts(lilypond_file):
     """
     rhythmic_staff = lilypond_file[_score.Score][-1]
     first_leaf = _get.leaf(rhythmic_staff, 0)
-    markup = _markups.Markup(r"\markup I", direction=_enums.Up)
+    markup = _indicators.Markup(r"\markup I", direction=_enums.UP)
     _bind.attach(markup, first_leaf)
-    _overrides.tweak(markup).staff_padding = 11
-    _overrides.tweak(markup).transparent = "##t"
+    _overrides.tweaks(markup, r"- \tweak staff-padding 11")
+    _overrides.tweaks(markup, r"- \tweak transparent ##t")
     duration = _get.duration(rhythmic_staff)
     if _duration.Duration(6, 4) < duration:
         last_leaf = _get.leaf(rhythmic_staff, -1)
-        markup = _markups.Markup(r"\markup I", direction=_enums.Up)
+        markup = _indicators.Markup(r"\markup I", direction=_enums.UP)
         _bind.attach(markup, last_leaf)
-        _overrides.tweak(markup).staff_padding = 18
-        _overrides.tweak(markup).transparent = "##t"
+        _overrides.tweaks(markup, r"- \tweak staff-padding 18")
+        _overrides.tweaks(markup, r"- \tweak transparent ##t")
 
 
 def illustrate(item, **keywords):
@@ -251,6 +249,19 @@ def illustrate(item, **keywords):
     return method(item, **keywords)
 
 
+def lilypond(argument, tags=False):
+    """
+    Gets LilyPond format of ``argument``.
+    """
+    if not hasattr(argument, "_get_lilypond_format"):
+        raise Exception(f"no LilyPond format defined for {argument!r}.")
+    string = argument._get_lilypond_format()
+    if tags:
+        return string
+    string = _tag.remove_tags(string)
+    return string
+
+
 def make_piano_score(leaves=None, lowest_treble_pitch="B3"):
     r"""
     Makes piano score from ``leaves``.
@@ -260,7 +271,7 @@ def make_piano_score(leaves=None, lowest_treble_pitch="B3"):
         REGRESSION. Function preserves tweaks:
 
         >>> note = abjad.Note("c'4")
-        >>> abjad.tweak(note.note_head).color = "red"
+        >>> abjad.tweak(note.note_head, r"\tweak color #red")
         >>> score = abjad.illustrators.make_piano_score([note])
         >>> abjad.show(score) # doctest: +SKIP
 
@@ -287,10 +298,10 @@ def make_piano_score(leaves=None, lowest_treble_pitch="B3"):
             >>
 
         >>> chord = abjad.Chord("<c d a' bf'>4")
-        >>> abjad.tweak(chord.note_heads[0]).color = "red"
-        >>> abjad.tweak(chord.note_heads[1]).color = "red"
-        >>> abjad.tweak(chord.note_heads[2]).color = "blue"
-        >>> abjad.tweak(chord.note_heads[3]).color = "blue"
+        >>> abjad.tweak(chord.note_heads[0], r"\tweak color #red")
+        >>> abjad.tweak(chord.note_heads[1], r"\tweak color #red")
+        >>> abjad.tweak(chord.note_heads[2], r"\tweak color #blue")
+        >>> abjad.tweak(chord.note_heads[3], r"\tweak color #blue")
         >>> score = abjad.illustrators.make_piano_score([chord])
         >>> abjad.show(score) # doctest: +SKIP
 
@@ -330,10 +341,10 @@ def make_piano_score(leaves=None, lowest_treble_pitch="B3"):
         REGRESSION. Function preserves markup:
 
         >>> note = abjad.Chord("<c bf'>4")
-        >>> markup = abjad.Markup(r"\markup loco", direction=abjad.Up)
-        >>> abjad.attach(markup, chord)
-        >>> markup = abjad.Markup(r"\markup ped.", direction=abjad.Down)
-        >>> abjad.attach(markup, chord)
+        >>> markup = abjad.Markup(r"\markup loco")
+        >>> abjad.attach(markup, chord, direction=abjad.UP)
+        >>> markup = abjad.Markup(r"\markup ped.")
+        >>> abjad.attach(markup, chord, direction=abjad.DOWN)
         >>> score = abjad.illustrators.make_piano_score([chord])
         >>> abjad.show(score) # doctest: +SKIP
 
@@ -383,7 +394,7 @@ def make_piano_score(leaves=None, lowest_treble_pitch="B3"):
     score = _score.Score(name="Score")
     score.append(staff_group)
     for leaf in leaves:
-        markups = _get.indicators(leaf, _markups.Markup)
+        markup_wrappers = _get.indicators(leaf, _indicators.Markup, unwrap=False)
         written_duration = leaf.written_duration
         if isinstance(leaf, _score.Note):
             if leaf.written_pitch < lowest_treble_pitch:
@@ -415,18 +426,22 @@ def make_piano_score(leaves=None, lowest_treble_pitch="B3"):
         else:
             treble_leaf = copy.copy(leaf)
             bass_leaf = copy.copy(leaf)
-        for markup in markups:
+        for wrapper in markup_wrappers:
+            # markup = wrapper.indicator
+            markup = wrapper.unbundle_indicator()
             markup_copy = copy.copy(markup)
-            if markup.direction in (_enums.Up, None):
-                _bind.attach(markup_copy, treble_leaf)
+            if wrapper.direction in (_enums.UP, None):
+                _bind.attach(markup_copy, treble_leaf, direction=wrapper.direction)
             else:
-                _bind.attach(markup_copy, bass_leaf)
+                _bind.attach(markup_copy, bass_leaf, direction=wrapper.direction)
         treble_staff.append(treble_leaf)
         bass_staff.append(bass_leaf)
     if 0 < len(treble_staff):
-        _bind.attach(_indicators.Clef("treble"), treble_staff[0])
+        clef = _indicators.Clef("treble")
+        _bind.attach(clef, treble_staff[0])
     if 0 < len(bass_staff):
-        _bind.attach(_indicators.Clef("bass"), bass_staff[0])
+        clef = _indicators.Clef("bass")
+        _bind.attach(clef, bass_staff[0])
     return score
 
 
@@ -475,10 +490,10 @@ def selection_to_score_markup_string(selection):
     staff.lilypond_type = "RhythmicStaff"
     staff.remove_commands.append("Time_signature_engraver")
     staff.remove_commands.append("Staff_symbol_engraver")
-    _overrides.override(staff).Stem.direction = _enums.Up
+    _overrides.override(staff).Stem.direction = _enums.UP
     _overrides.override(staff).Stem.length = 5
     _overrides.override(staff).TupletBracket.bracket_visibility = True
-    _overrides.override(staff).TupletBracket.direction = _enums.Up
+    _overrides.override(staff).TupletBracket.direction = _enums.UP
     _overrides.override(staff).TupletBracket.minimum_length = 4
     _overrides.override(staff).TupletBracket.padding = 1.25
     _overrides.override(staff).TupletBracket.shorten_pair = "#'(-1 . -1.5)"
@@ -496,8 +511,8 @@ def selection_to_score_markup_string(selection):
     _overrides.setting(score).proportionalNotationDuration = False
     indent = 4 * " "
     strings = [r"\score", indent + "{"]
-    strings.extend([2 * indent + _ for _ in _format.lilypond(score).split("\n")])
-    strings.extend([2 * indent + _ for _ in _format.lilypond(layout_block).split("\n")])
+    strings.extend([2 * indent + _ for _ in lilypond(score).split("\n")])
+    strings.extend([2 * indent + _ for _ in lilypond(layout_block).split("\n")])
     strings.append(indent + "}")
     string = "\n".join(strings)
     return string
