@@ -5,8 +5,9 @@ import copy
 import dataclasses
 import typing
 
+from . import contributions as _contributions
 from . import enumerate as _enumerate
-from . import markups as _markups
+from . import indicators as _indicators
 from . import pcollections as _pcollections
 from . import pitch as _pitch
 from . import string as _string
@@ -23,15 +24,15 @@ class Instrument:
         >>> voice_1 = abjad.Voice("e'8 g'8 f'8 a'8")
         >>> flute = abjad.Flute()
         >>> abjad.attach(flute, voice_1[0], context='Voice')
-        >>> flute_markup = abjad.Markup(r'\markup (flute)', direction=abjad.Up)
-        >>> abjad.attach(flute_markup, voice_1[0])
+        >>> flute_markup = abjad.Markup(r'\markup (flute)')
+        >>> abjad.attach(flute_markup, voice_1[0], direction=abjad.UP)
         >>> abjad.attach(abjad.LilyPondLiteral(r'\voiceOne'), voice_1)
         >>> voice_2 = abjad.Voice("c'2")
         >>> abjad.attach(abjad.LilyPondLiteral(r'\voiceTwo'), voice_2)
         >>> viola = abjad.Viola()
         >>> abjad.attach(viola, voice_2[0], context='Voice')
-        >>> viola_markup = abjad.Markup(r'\markup (viola)', direction=abjad.Down)
-        >>> abjad.attach(viola_markup, voice_2[0])
+        >>> viola_markup = abjad.Markup(r'\markup (viola)')
+        >>> abjad.attach(viola_markup, voice_2[0], direction=abjad.DOWN)
         >>> staff = abjad.Staff([voice_1, voice_2], simultaneous=True)
         >>> abjad.show(staff) # doctest: +SKIP
 
@@ -73,8 +74,6 @@ class Instrument:
 
     """
 
-    ### CLASS VARIABLES ###
-
     __slots__ = (
         "_allowable_clefs",
         "_context",
@@ -90,15 +89,11 @@ class Instrument:
         "_starting_clefs",
     )
 
-    _format_slot = "opening"
-
-    _latent = True
-
-    _persistent = True
-
-    _redraw = True
-
-    ### INITIALIZER ###
+    _site: typing.ClassVar[str] = "opening"
+    _latent: typing.ClassVar[bool] = True
+    _persistent: typing.ClassVar[bool] = True
+    _redraw: typing.ClassVar[bool] = True
+    check_effective_context: typing.ClassVar[bool] = True
 
     def __init__(
         self,
@@ -118,13 +113,13 @@ class Instrument:
             name = str(name)
         self._name = name
         if markup is not None:
-            markup = _markups.Markup(str(markup))
+            markup = _indicators.Markup(str(markup))
         self._name_markup = markup
         if short_name is not None:
             short_name = str(short_name)
         self._short_name = short_name
         if short_markup is not None:
-            short_markup = _markups.Markup(str(short_markup))
+            short_markup = _indicators.Markup(str(short_markup))
         self._short_name_markup = short_markup
         allowable_clefs = allowable_clefs or ("treble",)
         self._allowable_clefs = allowable_clefs
@@ -146,8 +141,6 @@ class Instrument:
         self._performer_names = ["instrumentalist"]
         self._starting_clefs = copy.copy(allowable_clefs)
 
-    ### SPECIAL METHODS ###
-
     def __eq__(self, argument) -> bool:
         """
         Compares all nine initializer parameters.
@@ -178,8 +171,6 @@ class Instrument:
         """
         return f"{type(self).__name__}()"
 
-    ### PRIVATE PROPERTIES ###
-
     @property
     def _lilypond_type(self):
         if isinstance(self.context, type):
@@ -189,8 +180,6 @@ class Instrument:
         else:
             return type(self.context).__name__
 
-    ### PRIVATE METHODS ###
-
     def _attachment_test_all(self, leaf):
         assert hasattr(leaf, "written_duration")
         if leaf._has_indicator(Instrument):
@@ -198,6 +187,13 @@ class Instrument:
             return string
         return True
 
+    def _get_contributions(self, *, component=None, wrapper=None):
+        contributions = _contributions.ContributionsBySite()
+        strings = self._get_lilypond_format()
+        assert isinstance(strings, list), repr(strings)
+        contributions.opening.commands.extend(strings)
+        return contributions
+
     def _get_lilypond_format(self, context=None):
         return []
 
@@ -206,7 +202,7 @@ class Instrument:
             if self.name:
                 string = self.name
                 string = _string.capitalize_start(string)
-                markup = _markups.Markup(rf"\markup {string}")
+                markup = _indicators.Markup(rf"\markup {string}")
                 self._name_markup = markup
             else:
                 self._name_markup = None
@@ -214,12 +210,10 @@ class Instrument:
             if self.short_name:
                 string = self.short_name
                 string = _string.capitalize_start(string)
-                markup = _markups.Markup(rf"\markup {string}")
+                markup = _indicators.Markup(rf"\markup {string}")
             else:
                 self._short_name_markup = None
 
-    ### PUBLIC PROPERTIES ###
-
     @property
     def allowable_clefs(self):
         """
@@ -266,9 +260,9 @@ class Instrument:
             self._initialize_default_name_markups()
         if self._name_markup is None:
             return
-        if not isinstance(self._name_markup, _markups.Markup):
+        if not isinstance(self._name_markup, _indicators.Markup):
             assert isinstance(self._name_markup, str), repr(self._name_markup)
-            markup = _markups.Markup(rf"\markup {self._name_markup}")
+            markup = _indicators.Markup(rf"\markup {self._name_markup}")
             self._name_markup = markup
         if self._name_markup.string:
             return self._name_markup
@@ -339,11 +333,11 @@ class Instrument:
             self._initialize_default_name_markups()
         if self._short_name_markup is None:
             return
-        if not isinstance(self._short_name_markup, _markups.Markup):
+        if not isinstance(self._short_name_markup, _indicators.Markup):
             assert isinstance(self._short_name_markup, str), repr(
                 self._short_name_markup
             )
-            markup = _markups.Markup(rf"\markup {self._short_name_markup}")
+            markup = _indicators.Markup(rf"\markup {self._short_name_markup}")
             self._short_name_markup = markup
         if self._short_name_markup.string:
             return self._short_name_markup
@@ -387,7 +381,7 @@ class StringNumber:
         self.numbers = numbers_
 
     @property
-    def roman_numerals(self) -> typing.Tuple[str, ...]:
+    def roman_numerals(self) -> tuple[str, ...]:
         """
         Gets roman numerals of string number indicator.
 
@@ -414,7 +408,7 @@ class StringNumber:
         return tuple(result)
 
 
-@dataclasses.dataclass(slots=True)
+@dataclasses.dataclass(slots=True, unsafe_hash=True)
 class Tuning:
     """
     Tuning.
@@ -423,28 +417,18 @@ class Tuning:
 
         Violin tuning:
 
-        >>> abjad.Tuning(pitches=('G3', 'D4', 'A4', 'E5'))
-        Tuning(pitches=PitchSegment(items="g d' a' e''", item_class=NamedPitch))
+        >>> abjad.Tuning(pitches=("G3", "D4", "A4", "E5"))
+        Tuning(pitches=(NamedPitch('g'), NamedPitch("d'"), NamedPitch("a'"), NamedPitch("e''")))
 
     """
 
-    pitches: typing.Sequence
+    pitches: typing.Sequence[_pitch.NamedPitch] = ()
 
     def __post_init__(self):
-        if isinstance(self.pitches, type(self)):
-            self.pitches = self.pitches.pitches
-        self.pitches = _pcollections.PitchSegment(
-            items=self.pitches, item_class=_pitch.NamedPitch
-        )
-
-    def __hash__(self):
-        """
-        Hashes tuning.
-        """
-        return hash(repr(self))
+        self.pitches = tuple(_pitch.NamedPitch(_) for _ in self.pitches)
 
     @property
-    def pitch_ranges(self) -> typing.List[_pcollections.PitchRange]:
+    def pitch_ranges(self) -> list[_pcollections.PitchRange]:
         """
         Gets two-octave pitch-ranges for each pitch in this tuning.
 
@@ -461,13 +445,15 @@ class Tuning:
         """
         result = []
         for pitch in self.pitches or []:
-            pitch_range = _pcollections.PitchRange(f"[{pitch}, {pitch + 24}]")
+            pitch_range = _pcollections.PitchRange(
+                f"[{pitch.name}, {(pitch + 24).name}]"
+            )
             result.append(pitch_range)
         return result
 
     def get_pitch_ranges_by_string_number(
         self, string_number: StringNumber
-    ) -> typing.Tuple[_pcollections.PitchRange, ...]:
+    ) -> tuple[_pcollections.PitchRange, ...]:
         """
         Gets tuning pitch ranges by string number.
 
@@ -494,7 +480,7 @@ class Tuning:
 
     def get_pitches_by_string_number(
         self, string_number: StringNumber
-    ) -> typing.Tuple[_pitch.NamedPitch, ...]:
+    ) -> tuple[_pitch.NamedPitch, ...]:
         """
         Gets tuning pitches by string number.
 
@@ -543,7 +529,7 @@ class Tuning:
             >>> voicings = tuning.voice_pitch_classes(
             ...     ('a', 'd'),
             ...     allow_open_strings=False,
-            ...     )
+            ... )
             >>> for voicing in voicings:
             ...     voicing
             ...
@@ -603,13 +589,11 @@ class Tuning:
         permutations = _enumerate.yield_permutations(pitch_classes)
         permutations = set([tuple(_) for _ in permutations])
         pitch_ranges = self.pitch_ranges
-        result: typing.List[
-            typing.Tuple[typing.Union[_pitch.NamedPitch, None], ...]
-        ] = []
+        result: list[tuple[_pitch.NamedPitch | None, ...]] = []
         for permutation in permutations:
-            sequences: typing.List = []
+            sequences: list = []
             for pitch_range, pitch_class in zip(pitch_ranges, permutation):
-                pitches: typing.List[typing.Optional[_pitch.NamedPitch]]
+                pitches: list[_pitch.NamedPitch | None]
                 if pitch_class is None:
                     sequences.append([None])
                     continue
@@ -1467,7 +1451,7 @@ class Cello(Instrument):
 
             >>> cello = abjad.Cello()
             >>> cello.default_tuning
-            Tuning(pitches=PitchSegment(items="c, g, d a", item_class=NamedPitch))
+            Tuning(pitches=(NamedPitch('c,'), NamedPitch('g,'), NamedPitch('d'), NamedPitch('a')))
 
         Returns tuning.
         """
@@ -1719,7 +1703,7 @@ class Contrabass(Instrument):
 
             >>> contrabass = abjad.Contrabass()
             >>> contrabass.default_tuning
-            Tuning(pitches=PitchSegment(items="c,, a,, d, g,", item_class=NamedPitch))
+            Tuning(pitches=(NamedPitch('c,,'), NamedPitch('a,,'), NamedPitch('d,'), NamedPitch('g,')))
 
         Returns tuning.
         """
@@ -2278,7 +2262,7 @@ class Guitar(Instrument):
 
             >>> guitar = abjad.Guitar()
             >>> guitar.default_tuning
-            Tuning(pitches=PitchSegment(items="e, a, d g b e'", item_class=NamedPitch))
+            Tuning(pitches=(NamedPitch('e,'), NamedPitch('a,'), NamedPitch('d'), NamedPitch('g'), NamedPitch('b'), NamedPitch("e'")))
 
         Returns tuning.
         """
@@ -2367,7 +2351,7 @@ class Harpsichord(Instrument):
         >>> staff_group = abjad.StaffGroup(
         ...     [upper_staff, lower_staff],
         ...     lilypond_type='PianoStaff',
-        ...     )
+        ... )
         >>> harpsichord = abjad.Harpsichord()
         >>> abjad.attach(harpsichord, staff_group[0][0])
         >>> abjad.attach(abjad.Clef('bass'), lower_staff[0])
@@ -3439,7 +3423,7 @@ class Viola(Instrument):
 
             >>> viola = abjad.Viola()
             >>> viola.default_tuning
-            Tuning(pitches=PitchSegment(items="c g d' a'", item_class=NamedPitch))
+            Tuning(pitches=(NamedPitch('c'), NamedPitch('g'), NamedPitch("d'"), NamedPitch("a'")))
 
         Returns tuning.
         """
@@ -3516,7 +3500,7 @@ class Violin(Instrument):
 
             >>> violin = abjad.Violin()
             >>> violin.default_tuning
-            Tuning(pitches=PitchSegment(items="g d' a' e''", item_class=NamedPitch))
+            Tuning(pitches=(NamedPitch('g'), NamedPitch("d'"), NamedPitch("a'"), NamedPitch("e''")))
 
         Returns tuning.
         """
