@@ -448,21 +448,21 @@ def _set_leaf_duration(leaf, new_duration):
         for indicator in _get.indicators(following_leaf):
             if i != following_leaf_count - 1:
                 if (
-                    getattr(indicator, "_time_orientation", _enums.Left)
-                    != _enums.Middle
+                    getattr(indicator, "_time_orientation", _enums.LEFT)
+                    != _enums.MIDDLE
                 ):
                     _bind.detach(indicator, following_leaf)
             elif (
-                getattr(indicator, "_time_orientation", _enums.Left) != _enums.Right
-                and getattr(indicator, "_time_orientation", _enums.Left)
-                != _enums.Middle
+                getattr(indicator, "_time_orientation", _enums.LEFT) != _enums.RIGHT
+                and getattr(indicator, "_time_orientation", _enums.LEFT)
+                != _enums.MIDDLE
             ):
                 _bind.detach(indicator, following_leaf)
         _bind.detach(_score.BeforeGraceContainer, following_leaf)
         following_leaves.append(following_leaf)
     if following_leaf_count > 0:
         for indicator in _get.indicators(leaf):
-            if getattr(indicator, "_time_orientation", _enums.Left) == _enums.Right:
+            if getattr(indicator, "_time_orientation", _enums.LEFT) == _enums.RIGHT:
                 _bind.detach(indicator, leaf)
     all_leaves = [leaf] + following_leaves
     assert len(all_leaves) == len(new_leaves)
@@ -480,7 +480,7 @@ def _set_leaf_duration(leaf, new_duration):
     index = logical_tie_leaves.index(leaf)
     next_ = index + 1
     logical_tie_leaves[next_:next_] = following_leaves
-    if 1 < len(logical_tie_leaves) and isinstance(leaf, (_score.Note, _score.Chord)):
+    if 1 < len(logical_tie_leaves) and isinstance(leaf, _score.Note | _score.Chord):
         _spanners.tie(logical_tie_leaves)
     if isinstance(components[0], _score.Leaf):
         assert isinstance(all_leaves, list)
@@ -703,12 +703,12 @@ def _split_leaf_by_durations(leaf, durations, cyclic=False):
     last_result_leaf = result_leaves[-1]
     for indicator in _get.indicators(leaf):
         _bind.detach(indicator, leaf)
-        direction = getattr(indicator, "_time_orientation", _enums.Left)
-        if direction is _enums.Left:
+        direction = getattr(indicator, "_time_orientation", _enums.LEFT)
+        if direction is _enums.LEFT:
             _bind.attach(indicator, first_result_leaf)
-        elif direction == _enums.Right:
+        elif direction == _enums.RIGHT:
             _bind.attach(indicator, last_result_leaf)
-        elif direction == _enums.Middle:
+        elif direction == _enums.MIDDLE:
             _bind.attach(indicator, first_result_leaf)
             indicator_copy = python_copy.copy(indicator)
             _bind.attach(indicator_copy, last_result_leaf)
@@ -723,7 +723,7 @@ def _split_leaf_by_durations(leaf, durations, cyclic=False):
     if isinstance(result_components[0], _score.Tuplet):
         fuse(result_components)
     # tie split notes
-    if isinstance(leaf, (_score.Note, _score.Chord)) and 1 < len(result_leaves):
+    if isinstance(leaf, _score.Note | _score.Chord) and 1 < len(result_leaves):
         _attach_tie_to_leaves(result_leaves)
     if originally_repeat_tied and not result_leaves[0]._has_indicator(
         _indicators.RepeatTie
@@ -1241,7 +1241,7 @@ def fuse(argument) -> _score.Tuplet | list[_score.Leaf]:
         result = _fuse([argument])
     else:
         result = _fuse(list(argument))
-    assert isinstance(result, (list, _score.Tuplet)), repr(result)
+    assert isinstance(result, list | _score.Tuplet), repr(result)
     return result
 
 
@@ -1574,12 +1574,12 @@ def replace(argument, recipients, wrappers=False):
 
     Returns none.
     """
-    if isinstance(argument, (list, _select.Selection)):
-        donors = argument
-    else:
+    if isinstance(argument, _score.Component):
         donors = [argument]
+    else:
+        donors = argument
     assert _are_contiguous_same_parent(donors)
-    if not isinstance(recipients, (list, _select.Selection)):
+    if not isinstance(recipients, list):
         if isinstance(recipients, _score.Component):
             recipients = [recipients]
         else:
@@ -1794,7 +1794,7 @@ def scale(argument, multiplier) -> None:
     if hasattr(argument, "_scale"):
         argument._scale(multiplier)
     else:
-        assert isinstance(argument, (list, _select.Selection))
+        assert isinstance(argument, list)
         for component in argument:
             component._scale(multiplier)
 
@@ -1980,13 +1980,13 @@ def split(argument, durations, cyclic=False):
         ...     r"c'4 \p \< cs' d' ds' \f",
         ...     name='Voice_2',
         ...     )
-        >>> abjad.override(voice_1).Stem.direction = abjad.Up
-        >>> abjad.override(voice_1).Slur.direction = abjad.Up
+        >>> abjad.override(voice_1).Stem.direction = abjad.UP
+        >>> abjad.override(voice_1).Slur.direction = abjad.UP
         >>> container = abjad.Container(
         ...     [voice_1, voice_2],
         ...     simultaneous=True,
         ...     )
-        >>> abjad.override(voice_2).Stem.direction = abjad.Down
+        >>> abjad.override(voice_2).Stem.direction = abjad.DOWN
         >>> staff = abjad.Staff([container])
         >>> abjad.show(staff) # doctest: +SKIP
 
@@ -2297,9 +2297,9 @@ def split(argument, durations, cyclic=False):
         result.append(remaining_components)
     # partition split components according to input durations
     result = _sequence.flatten(result, depth=-1)
-    result = _select.partition_by_durations(result, durations_copy, fill=_enums.Exact)
+    result = _select.partition_by_durations(result, durations_copy, fill=_enums.EXACT)
     # return list of shards
-    assert all(isinstance(_, (list, _select.Selection)) for _ in result)
+    assert all(isinstance(_, list) for _ in result)
     return result
 
 
@@ -2376,7 +2376,7 @@ def swap(argument, container):
 
     Returns none.
     """
-    if isinstance(argument, (list, _select.Selection)):
+    if isinstance(argument, list):
         donors = argument
     else:
         assert isinstance(argument, _score.Component)
@@ -2655,12 +2655,12 @@ def wrap(argument, container):
         ...     time_signature = abjad.get.effective(component, prototype)
         ...     print(component, time_signature)
         ...
-        Staff("{ c'4 d'4 e'4 f'4 }") 3/8
-        Container("c'4 d'4 e'4 f'4") 3/8
-        c'4 3/8
-        d'4 3/8
-        e'4 3/8
-        f'4 3/8
+        Staff("{ c'4 d'4 e'4 f'4 }") TimeSignature(pair=(3, 8), hide=False, partial=None)
+        Container("c'4 d'4 e'4 f'4") TimeSignature(pair=(3, 8), hide=False, partial=None)
+        Note("c'4") TimeSignature(pair=(3, 8), hide=False, partial=None)
+        Note("d'4") TimeSignature(pair=(3, 8), hide=False, partial=None)
+        Note("e'4") TimeSignature(pair=(3, 8), hide=False, partial=None)
+        Note("f'4") TimeSignature(pair=(3, 8), hide=False, partial=None)
 
     Returns none.
     """
@@ -2670,7 +2670,6 @@ def wrap(argument, container):
         selection = [argument]
     else:
         selection = argument
-    assert isinstance(selection, (list, _select.Selection)), repr(selection)
     parent, start, stop = _get_parent_and_start_stop_indices(
         selection, ignore_before_after_grace=True
     )
