@@ -1,18 +1,15 @@
-import typing
-
-from . import _iterate
+from . import _indent, _iterate
 from . import bind as _bind
 from . import duration as _duration
-from . import format as _format
+from . import indicators as _indicators
 from . import iterate as iterate_
 from . import mutate as _mutate
-from . import overrides as _overrides
 from . import parentage as _parentage
-from . import pcollections as _pcollections
 from . import score as _score
 from . import select as _select
 from . import spanners as _spanners
 from . import tag as _tag
+from . import tweaks as _tweaks
 from . import typings as _typings
 
 
@@ -138,9 +135,7 @@ class OnBeatGraceContainer(_score.Container):
         anchor_voice = _parentage.Parentage(anchor_leaf).get(_score.Voice)
         final_anchor_leaf = _iterate._get_leaf(anchor_voice, -1)
         next_leaf = _iterate._get_leaf(final_anchor_leaf, 1)
-        literal = _overrides.LilyPondLiteral(
-            r"\oneVoice", format_slot="absolute_before"
-        )
+        literal = _indicators.LilyPondLiteral(r"\oneVoice", site="absolute_before")
         if next_leaf._has_indicator(literal):
             return
         if isinstance(next_leaf._parent, OnBeatGraceContainer):
@@ -155,47 +150,37 @@ class OnBeatGraceContainer(_score.Container):
     def _format_invocation(self):
         return r'\context Voice = "On_Beat_Grace_Container"'
 
-    def _format_open_brackets_slot(self, bundle):
+    def _format_open_brackets_site(self, contributions):
         result = []
         if self.identifier:
             open_bracket = f"{{   {self.identifier}"
         else:
             open_bracket = "{"
         brackets_open = [open_bracket]
-        overrides = bundle.grob_overrides
-        settings = bundle.context_settings
+        overrides = contributions.grob_overrides
+        settings = contributions.context_settings
         if overrides or settings:
             contributions = [self._format_invocation(), r"\with", "{"]
             contributions = self._tag_strings(contributions)
-            contributions = tuple(contributions)
-            identifier_pair = ("context_brackets", "open")
-            result.append((identifier_pair, contributions))
-            contributions = [_format.INDENT + _ for _ in overrides]
+            result.extend(contributions)
+            contributions = [_indent.INDENT + _ for _ in overrides]
             contributions = self._tag_strings(contributions)
-            contributions = tuple(contributions)
-            identifier_pair = ("overrides", "overrides")
-            result.append((identifier_pair, contributions))
-            contributions = [_format.INDENT + _ for _ in settings]
+            result.extend(contributions)
+            contributions = [_indent.INDENT + _ for _ in settings]
             contributions = self._tag_strings(contributions)
-            contributions = tuple(contributions)
-            identifier_pair = ("settings", "settings")
-            result.append((identifier_pair, contributions))
+            result.extend(contributions)
             contributions = [f"}} {brackets_open[0]}"]
             contributions = ["}", open_bracket]
             contributions = self._tag_strings(contributions)
-            contributions = tuple(contributions)
-            identifier_pair = ("context_brackets", "open")
-            result.append((identifier_pair, contributions))
+            result.extend(contributions)
         else:
             contribution = self._format_invocation()
             contribution += f" {brackets_open[0]}"
             contributions = [contribution]
             contributions = [self._format_invocation(), open_bracket]
             contributions = self._tag_strings(contributions)
-            contributions = tuple(contributions)
-            identifier_pair = ("context_brackets", "open")
-            result.append((identifier_pair, contributions))
-        return tuple(result)
+            result.extend(contributions)
+        return result
 
     def _get_on_beat_anchor_leaf(self):
         container = self._parent
@@ -238,12 +223,12 @@ class OnBeatGraceContainer(_score.Container):
 
     def _match_anchor_leaf(self):
         first_grace = _iterate._get_leaf(self, 0)
-        if not isinstance(first_grace, (_score.Note, _score.Chord)):
+        if not isinstance(first_grace, _score.Note | _score.Chord):
             message = "must start with note or chord:\n"
             message += f"    {repr(self)}"
             raise Exception(message)
         anchor_leaf = self._get_on_beat_anchor_leaf()
-        if isinstance(anchor_leaf, (_score.Note, _score.Chord)) and isinstance(
+        if isinstance(anchor_leaf, _score.Note | _score.Chord) and isinstance(
             first_grace, (_score.Note, _score.Chord)
         ):
             if isinstance(first_grace, _score.Note):
@@ -251,13 +236,13 @@ class OnBeatGraceContainer(_score.Container):
                 _mutate.replace(first_grace, chord)
                 first_grace = chord
             generator = iterate_.pitches(anchor_leaf)
-            anchor_pitches = _pcollections.PitchSet.from_pitches(generator)
+            anchor_pitches = list(generator)
             highest_pitch = list(sorted(anchor_pitches))[-1]
             if highest_pitch not in first_grace.note_heads:
                 first_grace.note_heads.append(highest_pitch)
             grace_mate_head = first_grace.note_heads.get(highest_pitch)
-            _overrides.tweak(grace_mate_head).font_size = 0
-            _overrides.tweak(grace_mate_head).transparent = True
+            _tweaks.tweak(grace_mate_head, r"\tweak font-size 0")
+            _tweaks.tweak(grace_mate_head, r"\tweak transparent ##t")
 
     def _set_leaf_durations(self):
         if self.leaf_duration is None:
@@ -271,7 +256,7 @@ class OnBeatGraceContainer(_score.Container):
     ### PUBLIC PROPERTIES ###
 
     @property
-    def leaf_duration(self) -> typing.Optional[_duration.Duration]:
+    def leaf_duration(self) -> _duration.Duration | None:
         """
         Gets leaf duration.
         """
@@ -849,12 +834,12 @@ def on_beat_grace_container(
         raise Exception(message)
     if font_size is not None:
         string = rf"\set fontSize = #{font_size}"
-        literal = _overrides.LilyPondLiteral(string)
+        literal = _indicators.LilyPondLiteral(string)
         _bind.attach(literal, on_beat_grace_container, tag=_site(1))
     if not do_not_beam:
         _spanners.beam(on_beat_grace_container[:])
     if not do_not_slash:
-        literal = _overrides.LilyPondLiteral(r"\slash")
+        literal = _indicators.LilyPondLiteral(r"\slash")
         _bind.attach(literal, on_beat_grace_container[0], tag=_site(2))
     if not do_not_slur:
         _spanners.slur(on_beat_grace_container[:])
@@ -865,24 +850,22 @@ def on_beat_grace_container(
         4: r"\voiceFour",
     }
     first_grace = _iterate._get_leaf(on_beat_grace_container, 0)
-    one_voice_literal = _overrides.LilyPondLiteral(
-        r"\oneVoice", format_slot="absolute_before"
+    one_voice_literal = _indicators.LilyPondLiteral(
+        r"\oneVoice", site="absolute_before"
     )
     string = voice_number_to_string.get(grace_voice_number, None)
     if string is not None:
         literal
         _bind.detach(one_voice_literal, anchor_leaf)
-        _bind.attach(_overrides.LilyPondLiteral(string), first_grace, tag=_site(3))
+        _bind.attach(_indicators.LilyPondLiteral(string), first_grace, tag=_site(3))
     string = voice_number_to_string.get(anchor_voice_number, None)
     if string is not None:
         _bind.detach(one_voice_literal, anchor_leaf)
-        _bind.attach(_overrides.LilyPondLiteral(string), anchor_leaf, tag=_site(4))
+        _bind.attach(_indicators.LilyPondLiteral(string), anchor_leaf, tag=_site(4))
     if not do_not_stop_polyphony:
         last_anchor_leaf = _iterate._get_leaf(anchor_voice_selection, -1)
         next_leaf = _iterate._get_leaf(last_anchor_leaf, 1)
         if next_leaf is not None:
-            literal = _overrides.LilyPondLiteral(
-                r"\oneVoice", format_slot="absolute_before"
-            )
+            literal = _indicators.LilyPondLiteral(r"\oneVoice", site="absolute_before")
             _bind.attach(literal, next_leaf, tag=_site(5))
     return on_beat_grace_container
