@@ -10,40 +10,43 @@ from . import dynamic as _dynamic
 from . import enums as _enums
 from . import indicators as _indicators
 from . import iterate as iterate_
-from . import overrides as _overrides
 from . import parentage as _parentage
 from . import score as _score
 from . import select as _select
 from . import sequence as _sequence
 from . import tag as _tag
+from . import tweaks as _tweaks
 from . import typings as _typings
 
 
 def _apply_tweaks(argument, tweaks, i=None, total=None):
     if not tweaks:
-        return
-    manager = _overrides.tweak(argument)
+        return argument
+    if i is not None:
+        assert isinstance(i, int), repr(i)
+    if total is not None:
+        assert isinstance(total, int), repr(total)
+    tweak_objects = []
     for item in tweaks:
         if isinstance(item, tuple):
             assert len(item) == 2
-            manager_, i_ = item
-            if 0 <= i_ and i_ != i:
+            item, index = item
+            if 0 <= index and index != i:
                 continue
-            if i_ < 0 and i_ != -(total - i):
+            if index < 0 and index != -(total - i):
                 continue
-        else:
-            manager_ = item
-        assert isinstance(manager_, _overrides.TweakInterface)
-        tuples = manager_._get_attribute_tuples()
-        for attribute, value in tuples:
-            setattr(manager, attribute, value)
+        assert isinstance(item, _tweaks.Tweak), repr(item)
+        tweak_objects.append(item)
+    bundle = _tweaks.bundle(argument, *tweak_objects)
+    return bundle
 
 
 def beam(
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
     beam_lone_notes: bool = False,
-    beam_rests: typing.Optional[bool] = True,
+    beam_rests: bool | None = True,
+    direction: _enums.Vertical | None = None,
     durations: typing.Sequence[_duration.Duration] = None,
     selector: typing.Callable = lambda _: _select.leaves(_),
     span_beam_count: int = None,
@@ -58,7 +61,7 @@ def beam(
     ..  container:: example
 
         >>> staff = abjad.Staff("c'8 d' e' f'")
-        >>> abjad.beam(staff[:])
+        >>> abjad.beam(staff[:], direction=abjad.UP)
         >>> abjad.show(staff) # doctest: +SKIP
 
         ..  docs::
@@ -68,7 +71,7 @@ def beam(
             \new Staff
             {
                 c'8
-                [
+                ^ [
                 d'8
                 e'8
                 f'8
@@ -82,7 +85,7 @@ def beam(
     silent_prototype = (_score.MultimeasureRest, _score.Rest, _score.Skip)
 
     def _is_beamable(argument, beam_rests=False):
-        if isinstance(argument, (_score.Chord, _score.Note)):
+        if isinstance(argument, _score.Chord | _score.Note):
             if 0 < argument.written_duration.flag_count:
                 return True
         if beam_rests and isinstance(argument, silent_prototype):
@@ -119,7 +122,7 @@ def beam(
         start_beam_ = start_beam or _indicators.StartBeam()
         stop_beam_ = stop_beam or _indicators.StopBeam()
         _bind.detach(_indicators.StartBeam, start_leaf)
-        _bind.attach(start_beam_, start_leaf, tag=tag)
+        _bind.attach(start_beam_, start_leaf, direction=direction, tag=tag)
         _bind.detach(_indicators.StopBeam, stop_leaf)
         _bind.attach(stop_beam_, stop_leaf, tag=tag)
 
@@ -128,7 +131,7 @@ def beam(
         staff = _parentage.Parentage(start_leaf).get(_score.Staff)
         lilypond_type = getattr(staff, "lilypond_type", "Staff")
         string = rf"\override {lilypond_type}.Stem.stemlet-length = {stemlet_length}"
-        literal = _overrides.LilyPondLiteral(string)
+        literal = _indicators.LilyPondLiteral(string)
         for indicator in start_leaf._get_indicators():
             if indicator == literal:
                 break
@@ -137,7 +140,7 @@ def beam(
         staff = _parentage.Parentage(stop_leaf).get(_score.Staff)
         lilypond_type = getattr(staff, "lilypond_type", "Staff")
         string = rf"\revert {lilypond_type}.Stem.stemlet-length"
-        literal = _overrides.LilyPondLiteral(string)
+        literal = _indicators.LilyPondLiteral(string)
         for indicator in stop_leaf._get_indicators():
             if indicator == literal:
                 break
@@ -254,7 +257,7 @@ def beam(
 
 def glissando(
     argument,
-    *tweaks: _overrides.IndexedTweakManager,
+    *tweaks,
     allow_repeats: bool = False,
     allow_ties: bool = False,
     hide_middle_note_heads: bool = False,
@@ -406,8 +409,8 @@ def glissando(
                 a8
                 \glissando
                 b8
-                ~
                 \glissando
+                ~
                 b8
                 \glissando
                 c'8
@@ -415,13 +418,13 @@ def glissando(
                 c'8
                 \glissando
                 d'8
-                ~
                 \glissando
+                ~
                 d'8
             }
 
-        Ties are excluded when repeated pitches are not allowed because all
-        ties comprise repeated pitches.
+        Ties are excluded when repeated pitches are not allowed because all ties
+        comprise repeated pitches.
 
     ..  container:: example
 
@@ -500,7 +503,7 @@ def glissando(
 
     ..  container:: example
 
-        With ``hide_middle_note_heads`` set to true:
+        With ``hide_middle_note_heads=True``:
 
         >>> staff = abjad.Staff("c'8 d'8 e'8 f'8")
         >>> abjad.glissando(
@@ -532,8 +535,7 @@ def glissando(
 
     ..  container:: example
 
-        With ``hide_middle_note_heads`` and ``hide_middle_stems`` both set to
-        true:
+        With ``hide_middle_note_heads=True`` and ``hide_middle_stems=True``:
 
         >>> staff = abjad.Staff("c'8 d'8 e'8 f'8")
         >>> abjad.glissando(
@@ -569,11 +571,11 @@ def glissando(
             }
 
         ..  note:: Respects ``hide_middle_stems`` only when
-            ``hide_middle_note_heads`` is set to true.
+            ``hide_middle_note_heads=True``.
 
     ..  container:: example
 
-        With right-broken set to true:
+        With ``right_broken=True``:
 
         >>> staff = abjad.Staff("c'8 d'8 e'8 f'8")
         >>> abjad.glissando(
@@ -605,8 +607,7 @@ def glissando(
 
     ..  container:: example
 
-        With right-broken set to true and ``hide_middle_note_heads`` set to
-        true:
+        With ``right_broken=True`` and ``hide_middle_note_heads=True``:
 
         >>> staff = abjad.Staff("c'8 d'8 e'8 f'8")
         >>> abjad.glissando(
@@ -664,8 +665,8 @@ def glissando(
 
     ..  container:: example
 
-        With ``right_broken``, ``hide_middle_note_heads`` and
-        ``right_broken_show_next`` all set to true:
+        With ``right_broken=True``, ``hide_middle_note_heads=True`` and
+        ``right_broken_show_next=True``:
 
         >>> staff = abjad.Staff("c'8 d'8 e'8 f'8")
         >>> abjad.glissando(
@@ -740,8 +741,7 @@ def glissando(
 
     ..  container:: example
 
-        With left-broken set to true (and ``hide_middle_note_heads`` set to
-        true):
+        With ``left_broken=True`` (and ``hide_middle_note_heads=True``):
 
         >>> staff = abjad.Staff("c'8 d'8 e'8 f'8")
         >>> abjad.glissando(
@@ -789,17 +789,16 @@ def glissando(
             f'8
         }
 
-        ..  note:: Respects left-broken only with ``hide_middle_note_heads``
-            set to true.
+        ..  note:: Respects left-broken only with ``hide_middle_note_heads=True``.
 
     ..  container:: example
 
-        With tweaks applied to every glissando command:
+        Tweaks apply to every glissando:
 
         >>> staff = abjad.Staff("c'8 d'8 e'8 f'8")
         >>> abjad.glissando(
         ...     staff[:],
-        ...     abjad.tweak("#'trill").style,
+        ...     abjad.Tweak(r"- \tweak style #'trill"),
         ... )
         >>> abjad.show(staff) # doctest: +SKIP
 
@@ -823,9 +822,10 @@ def glissando(
 
     ..  container:: example
 
-        With zero padding on fixed pitch:
+        With ``zero_padding=True`` on fixed pitch:
 
         >>> staff = abjad.Staff("d'8 d'4. d'4. d'8")
+
         >>> abjad.glissando(
         ...     staff[:],
         ...     allow_repeats=True,
@@ -864,7 +864,7 @@ def glissando(
 
     ..  container:: example
 
-        With zero padding on moving pitch:
+        With ``zero_padding=True`` on changing pitches:
 
         >>> staff = abjad.Staff("c'8. d'8. e'8. f'8.")
         >>> abjad.glissando(
@@ -907,8 +907,8 @@ def glissando(
         >>> staff = abjad.Staff("d'4 d' d' d'")
         >>> abjad.glissando(
         ...     staff[:],
-        ...     (abjad.tweak("#red").color, 0),
-        ...     (abjad.tweak("#red").color, -1),
+        ...     (abjad.Tweak(r"- \tweak color #red"), 0),
+        ...     (abjad.Tweak(r"- \tweak color #red"), -1),
         ...     allow_repeats=True,
         ...     zero_padding=True,
         ... )
@@ -926,8 +926,8 @@ def glissando(
             \new Staff
             {
                 d'4
-                - \abjad-zero-padding-glissando
                 - \tweak color #red
+                - \abjad-zero-padding-glissando
                 \glissando
                 \once \override NoteHead.X-extent = #'(0 . 0)
                 \once \override NoteHead.transparent = ##t
@@ -937,8 +937,8 @@ def glissando(
                 \once \override NoteHead.X-extent = #'(0 . 0)
                 \once \override NoteHead.transparent = ##t
                 d'4
-                - \abjad-zero-padding-glissando
                 - \tweak color #red
+                - \abjad-zero-padding-glissando
                 \glissando
                 d'4
             }
@@ -1016,7 +1016,7 @@ def glissando(
             if right_broken is True:
                 should_attach_glissando = True
                 deactivate_glissando = True
-        elif not isinstance(leaf, (_score.Chord, _score.Note)):
+        elif not isinstance(leaf, _score.Chord | _score.Note):
             pass
         elif allow_repeats and allow_ties:
             should_attach_glissando = True
@@ -1034,7 +1034,7 @@ def glissando(
                 r"\once \override Dots.transparent = ##t",
                 r"\once \override Stem.transparent = ##t",
             ]
-            literal = _overrides.LilyPondLiteral(strings)
+            literal = _indicators.LilyPondLiteral(strings)
             _bind.attach(literal, leaf, tag=tag.append(_tag.Tag("abjad.glissando(-1)")))
         if hide_middle_note_heads:
             if leaf is not leaves[0]:
@@ -1053,7 +1053,7 @@ def glissando(
                             r"\override Stem.transparent = ##t",
                         ]
                     )
-                literal = _overrides.LilyPondLiteral(strings)
+                literal = _indicators.LilyPondLiteral(strings)
                 if right_broken is True:
                     _bind.attach(
                         literal,
@@ -1081,7 +1081,7 @@ def glissando(
                             r"\override Stem.transparent = ##t",
                         ]
                     )
-                literal = _overrides.LilyPondLiteral(strings)
+                literal = _indicators.LilyPondLiteral(strings)
                 _bind.attach(
                     literal,
                     leaf,
@@ -1091,7 +1091,7 @@ def glissando(
                 )
             elif left_broken and leaf is leaves[1]:
                 string = r"\override NoteColumn.glissando-skip = ##t"
-                literal = _overrides.LilyPondLiteral(string)
+                literal = _indicators.LilyPondLiteral(string)
                 _bind.attach(
                     literal,
                     leaf,
@@ -1112,7 +1112,7 @@ def glissando(
                     )
                 if right_broken:
                     deactivate_glissando = True
-                    literal = _overrides.LilyPondLiteral(strings)
+                    literal = _indicators.LilyPondLiteral(strings)
                     _bind.attach(
                         literal,
                         leaf,
@@ -1122,9 +1122,7 @@ def glissando(
                         .append(_tag.Tag("RIGHT_BROKEN")),
                     )
                     if right_broken_show_next:
-                        literal = _overrides.LilyPondLiteral(
-                            strings, format_slot="after"
-                        )
+                        literal = _indicators.LilyPondLiteral(strings, site="after")
                         _bind.attach(
                             literal,
                             leaf,
@@ -1134,7 +1132,7 @@ def glissando(
                             .append(_tag.Tag("RIGHT_BROKEN_SHOW_NEXT")),
                         )
                 else:
-                    literal = _overrides.LilyPondLiteral(strings)
+                    literal = _indicators.LilyPondLiteral(strings)
                     _bind.attach(
                         literal,
                         leaf,
@@ -1142,7 +1140,7 @@ def glissando(
                     )
         if should_attach_glissando:
             glissando = _indicators.Glissando(zero_padding=zero_padding)
-            _apply_tweaks(glissando, tweaks, i=i, total=total)
+            glissando = _apply_tweaks(glissando, tweaks, i=i, total=total)
             tag_ = tag.append(_tag.Tag("abjad.glissando(7)"))
             if deactivate_glissando:
                 tag_ = tag_.append(_tag.Tag("SHOW_TO_JOIN_BROKEN_SPANNERS"))
@@ -1151,8 +1149,9 @@ def glissando(
 
 def hairpin(
     descriptor: str,
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
+    direction: _enums.Vertical | None = None,
     selector: typing.Callable = lambda _: _select.leaves(_),
     tag: _tag.Tag = None,
 ) -> None:
@@ -1164,7 +1163,7 @@ def hairpin(
         With three-part string descriptor:
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> abjad.hairpin("p < f", staff[:])
+        >>> abjad.hairpin("p < f", staff[:], direction=abjad.UP)
         >>> abjad.override(staff[0]).DynamicLineSpanner.staff_padding = 4
         >>> abjad.show(staff) # doctest: +SKIP
 
@@ -1176,8 +1175,8 @@ def hairpin(
             {
                 \once \override DynamicLineSpanner.staff-padding = 4
                 c'4
-                \p
-                \<
+                ^ \p
+                ^ \<
                 d'4
                 e'4
                 f'4
@@ -1215,9 +1214,9 @@ def hairpin(
         >>> staff = abjad.Staff("c'4 d' e' f'")
         >>> start_dynamic = abjad.Dynamic("niente", command=r"\!")
         >>> start_hairpin = abjad.StartHairpin("o<|")
-        >>> abjad.tweak(start_hairpin).color = "#blue"
+        >>> bundle = abjad.bundle(start_hairpin, r"- \tweak color #blue")
         >>> stop_dynamic = abjad.Dynamic('"f"')
-        >>> abjad.hairpin([start_dynamic, start_hairpin, stop_dynamic], staff[:])
+        >>> abjad.hairpin([start_dynamic, bundle, stop_dynamic], staff[:])
         >>> abjad.override(staff[0]).DynamicLineSpanner.staff_padding = 4
         >>> abjad.show(staff) # doctest: +SKIP
 
@@ -1252,10 +1251,10 @@ def hairpin(
             }
 
     """
-    indicators: typing.List = []
-    start_dynamic: typing.Optional[_dynamic.Dynamic]
-    hairpin: typing.Optional[_indicators.StartHairpin]
-    stop_dynamic: typing.Optional[_dynamic.Dynamic]
+    indicators: list = []
+    start_dynamic: _dynamic.Dynamic | None
+    hairpin: _indicators.StartHairpin | None
+    stop_dynamic: _dynamic.Dynamic | None
     known_shapes = _indicators.StartHairpin("<").known_shapes
     if isinstance(descriptor, str):
         for string in descriptor.split():
@@ -1300,15 +1299,15 @@ def hairpin(
     stop_leaf = leaves[-1]
 
     if start_dynamic is not None:
-        _bind.attach(start_dynamic, start_leaf, tag=tag)
+        _bind.attach(start_dynamic, start_leaf, direction=direction, tag=tag)
     if hairpin is not None:
-        _bind.attach(hairpin, start_leaf, tag=tag)
+        _bind.attach(hairpin, start_leaf, direction=direction, tag=tag)
     if stop_dynamic is not None:
         _bind.attach(stop_dynamic, stop_leaf, tag=tag)
 
 
 def horizontal_bracket(
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
     selector: typing.Callable = lambda _: _select.leaves(_),
     start_group: _indicators.StartGroup = None,
@@ -1351,11 +1350,11 @@ def horizontal_bracket(
 
 
 def ottava(
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
     selector: typing.Callable = lambda _: _select.leaves(_),
     start_ottava: _indicators.Ottava = _indicators.Ottava(n=1),
-    stop_ottava: _indicators.Ottava = _indicators.Ottava(n=0, format_slot="after"),
+    stop_ottava: _indicators.Ottava = _indicators.Ottava(n=0, site="after"),
     tag: _tag.Tag = None,
 ) -> None:
     r"""
@@ -1394,8 +1393,9 @@ def ottava(
 
 
 def phrasing_slur(
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
+    direction: _enums.Vertical | None = None,
     selector: typing.Callable = lambda _: _select.leaves(_),
     start_phrasing_slur: _indicators.StartPhrasingSlur = None,
     stop_phrasing_slur: _indicators.StopPhrasingSlur = None,
@@ -1407,7 +1407,7 @@ def phrasing_slur(
     ..  container:: example
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> abjad.phrasing_slur(staff[:])
+        >>> abjad.phrasing_slur(staff[:], direction=abjad.UP)
         >>> abjad.show(staff) # doctest: +SKIP
 
         ..  docs::
@@ -1417,7 +1417,7 @@ def phrasing_slur(
             \new Staff
             {
                 c'4
-                \(
+                ^ \(
                 d'4
                 e'4
                 f'4
@@ -1435,12 +1435,12 @@ def phrasing_slur(
     stop_leaf = leaves[-1]
     start_phrasing_slur = start_phrasing_slur or _indicators.StartPhrasingSlur()
     stop_phrasing_slur = stop_phrasing_slur or _indicators.StopPhrasingSlur()
-    _bind.attach(start_phrasing_slur, start_leaf, tag=tag)
+    _bind.attach(start_phrasing_slur, start_leaf, direction=direction, tag=tag)
     _bind.attach(stop_phrasing_slur, stop_leaf, tag=tag)
 
 
 def piano_pedal(
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
     selector: typing.Callable = lambda _: _select.leaves(_),
     start_piano_pedal: _indicators.StartPianoPedal = None,
@@ -1490,8 +1490,9 @@ def piano_pedal(
 
 
 def slur(
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
+    direction: _enums.Vertical = None,
     selector: typing.Callable = lambda _: _select.leaves(_),
     start_slur: _indicators.StartSlur = None,
     stop_slur: _indicators.StopSlur = None,
@@ -1503,7 +1504,7 @@ def slur(
     ..  container:: example
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> abjad.slur(staff[:])
+        >>> abjad.slur(staff[:], direction=abjad.UP)
         >>> abjad.show(staff) # doctest: +SKIP
 
         ..  docs::
@@ -1513,7 +1514,7 @@ def slur(
             \new Staff
             {
                 c'4
-                (
+                ^ (
                 d'4
                 e'4
                 f'4
@@ -1529,13 +1530,14 @@ def slur(
     leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
-    _bind.attach(start_slur, start_leaf, tag=tag)
+    _bind.attach(start_slur, start_leaf, direction=direction, tag=tag)
     _bind.attach(stop_slur, stop_leaf, tag=tag)
 
 
 def text_spanner(
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
+    direction: _enums.Vertical | None = None,
     selector: typing.Callable = lambda _: _select.leaves(_),
     start_text_span: _indicators.StartTextSpan = None,
     stop_text_span: _indicators.StopTextSpan = None,
@@ -1554,7 +1556,9 @@ def text_spanner(
         ...     right_text=abjad.Markup(r"\markup \upright tasto"),
         ...     style="solid-line-with-arrow",
         ... )
-        >>> abjad.text_spanner(staff[:], start_text_span=start_text_span)
+        >>> abjad.text_spanner(
+        ...     staff[:], direction=abjad.UP, start_text_span=start_text_span
+        ... )
         >>> abjad.override(staff[0]).TextSpanner.staff_padding = 4
         >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
         >>> abjad.show(lilypond_file) # doctest: +SKIP
@@ -1570,7 +1574,7 @@ def text_spanner(
                 - \abjad-solid-line-with-arrow
                 - \tweak bound-details.left.text \markup \concat { \upright pont. \hspace #0.5 }
                 - \tweak bound-details.right.text \markup \upright tasto
-                \startTextSpan
+                ^ \startTextSpan
                 d'4
                 e'4
                 f'4
@@ -1671,14 +1675,14 @@ def text_spanner(
     leaves = _select.leaves(argument)
     start_leaf = leaves[0]
     stop_leaf = leaves[-1]
-    _bind.attach(start_text_span, start_leaf, tag=tag)
+    _bind.attach(start_text_span, start_leaf, direction=direction, tag=tag)
     _bind.attach(stop_text_span, stop_leaf, tag=tag)
 
 
 def tie(
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
-    direction: _enums.VerticalAlignment = None,
+    direction: _enums.Vertical | None = None,
     repeat: bool | _typings.IntegerPair | typing.Callable = False,
     selector: typing.Callable = lambda _: _select.leaves(_),
     tag: _tag.Tag = None,
@@ -1689,7 +1693,7 @@ def tie(
     ..  container:: example
 
         >>> staff = abjad.Staff("c'4 c' c' c'")
-        >>> abjad.tie(staff[:])
+        >>> abjad.tie(staff[:], direction=abjad.UP)
         >>> abjad.show(staff) # doctest: +SKIP
 
         ..  docs::
@@ -1699,11 +1703,11 @@ def tie(
             \new Staff
             {
                 c'4
-                ~
+                ^ ~
                 c'4
-                ~
+                ^ ~
                 c'4
-                ~
+                ^ ~
                 c'4
             }
 
@@ -1890,24 +1894,24 @@ def tie(
     if len(leaves) < 2:
         raise Exception(f"must be two or more notes (not {leaves!r}).")
     for leaf in leaves:
-        if not isinstance(leaf, (_score.Note, _score.Chord)):
+        if not isinstance(leaf, _score.Note | _score.Chord):
             raise Exception(rf"tie note or chord (not {leaf!r}).")
     for current_leaf, next_leaf in _sequence.nwise(leaves):
         duration = current_leaf._get_duration()
         if inequality(duration):
             _bind.detach(_indicators.Tie, current_leaf)
             _bind.detach(_indicators.RepeatTie, next_leaf)
-            repeat_tie = _indicators.RepeatTie(direction=direction)
-            _bind.attach(repeat_tie, next_leaf, tag=tag)
+            repeat_tie = _indicators.RepeatTie()
+            _bind.attach(repeat_tie, next_leaf, direction=direction, tag=tag)
         else:
             _bind.detach(_indicators.Tie, current_leaf)
             _bind.detach(_indicators.RepeatTie, next_leaf)
-            tie = _indicators.Tie(direction=direction)
-            _bind.attach(tie, current_leaf, tag=tag)
+            tie = _indicators.Tie()
+            _bind.attach(tie, current_leaf, direction=direction, tag=tag)
 
 
 def trill_spanner(
-    argument: _score.Component | _select.Selection | typing.Sequence[_score.Component],
+    argument: _score.Component | typing.Sequence[_score.Component],
     *,
     selector: typing.Callable = lambda _: _select.leaves(_),
     start_trill_span: _indicators.StartTrillSpan = None,
